#!BPY

"""
Name: 'Export Collider Objects'
Blender: 245
Group: 'Export'
Tip: 'Exports a list of current scene objects having bounds set, ordered by bounds type'
"""
__author__ = "tachzusamm"

import Blender
import bpy
from Blender import Window


# script main function
# --------------------
def ExportColliders(filename):
    HullTypes = {"BOX" : 0, "SPHERE" : 1, "CYLINDER" : 2, "CONE" : 3, "TRIANGLEMESH" : 4, "CONVEXHULL" : 5}
    Result = "Found: "
    
    in_emode = Window.EditMode()
    if in_emode: Window.EditMode(0)
    
    scene = Blender.Scene.GetCurrent()
    
    file = open(filename, "wb")
    file.write("Active Scene: %s\n\n" % scene.getName())
    
    for hType in HullTypes:
        counter = 0
        #print hType
        file.write("scanning for objects with collision type '%s'\n" % hType)
        for obj in scene.objects:
            if obj.rbFlags & Blender.Object.RBFlags["BOUNDS"]:
                if obj.rbShapeBoundType  == HullTypes[hType]:
                    file.write("- %s\n" % obj.getName())
                    counter += 1
        file.write("%d objects with collision '%s' found\n\n" % (counter,hType))
        Result += ("%d %s  " % (counter,hType))
    
    file.write("done.\n")
    file.close()
    
    Blender.Draw.PupMenu('%s' % Result)
    
    if in_emode: Window.EditMode(1)
    Blender.Redraw()


# file selector
# -----------------------------------------------------------------------------
def FileSelectorEC(filename):
    if not filename.lower().endswith('.txt'):
        file_name += '.txt'
    ExportColliders(filename)

if __name__ == '__main__':
    Blender.Window.FileSelector(FileSelectorEC, "Export Colliders", Blender.sys.makename(ext='.txt'))

